--
-- PostgreSQL database dump
--

SET client_encoding = 'UNICODE';
SET check_function_bodies = false;

--
-- TOC entry 3 (OID 2072038)
-- Name: desktop; Type: SCHEMA; Schema: -; Owner: 
--

CREATE SCHEMA desktop AUTHORIZATION desktop;


SET SESSION AUTHORIZATION 'desktop';

SET search_path = desktop, pg_catalog;

--
-- TOC entry 8 (OID 2072043)
-- Name: app_configuration(text); Type: FUNCTION; Schema: desktop; Owner: desktop
--

CREATE FUNCTION app_configuration(text) RETURNS record
    AS 'select
 c.configuration,
 not a.available as "Hidden",
 coalesce(p.projectname_full||'' (''||fname||'')'',name) as "Name",
 a.genericname as "GenericName",
 coalesce(p.desc_short, a.comment) as "Comment",
 a.exec as "Exec"
from apps a
join app_configuration c on (c.app=a.fname)
left join project p on p.projectname_full=a.project
order by 1,2

'
    LANGUAGE sql;


--
-- TOC entry 13 (OID 2072057)
-- Name: concat_strings(text); Type: AGGREGATE; Schema: desktop; Owner: desktop
--

CREATE AGGREGATE concat_strings (
    BASETYPE = text,
    SFUNC = textcat,
    STYPE = text
);


--
-- TOC entry 6 (OID 2072059)
-- Name: flow_dot_nodes(text); Type: FUNCTION; Schema: desktop; Owner: desktop
--

CREATE FUNCTION flow_dot_nodes(text) RETURNS text
    AS ' SELECT desktop.concat_strings(
  DISTINCT ''\\t'' || wdbi.esc(''c'',"mime"."type") || ''[shape="box"];
''
 )
 FROM "app_input_view" "app_input", 
            "mime_view" "mime"
 WHERE ( "app_input"."mime" = "mime"."type" )
 AND mime LIKE coalesce($1,''%'')
'
    LANGUAGE sql;


--
-- TOC entry 7 (OID 2072060)
-- Name: flow_dot_edges(text); Type: FUNCTION; Schema: desktop; Owner: desktop
--

CREATE FUNCTION flow_dot_edges(text) RETURNS text
    AS 'SELECT
 desktop.concat_strings(
 ''\\t'' || wdbi.esc(''c'',type) || '' -> '' ||
 wdbi.esc(''c'',fname) || '';
'')
AS dot_edges
FROM (
 SELECT "mime"."type", "apps"."fname" 
 FROM "app_input_view" "app_input", 
            "mime_view" "mime", 
            "apps" "apps" 
 WHERE ( "app_input"."mime" = "mime"."type" 
 AND "app_input"."app" = "apps"."fname" )
) AS diagram
WHERE type like coalesce($1,''%'') OR fname like coalesce($1,''%'') 
'
    LANGUAGE sql;


--
-- TOC entry 9 (OID 2072061)
-- Name: app_mimetype(name); Type: FUNCTION; Schema: desktop; Owner: desktop
--

CREATE FUNCTION app_mimetype(name) RETURNS text
    AS 'select desktop.concat_strings(mime||'';'') from app_mime where app = $1'
    LANGUAGE sql;


--
-- TOC entry 10 (OID 2072062)
-- Name: app_mimetypes(name); Type: FUNCTION; Schema: desktop; Owner: desktop
--

CREATE FUNCTION app_mimetypes(name) RETURNS text
    AS 'select desktop.concat_strings(mime||'';'') from app_mime where app = $1'
    LANGUAGE sql;


--
-- TOC entry 11 (OID 2072063)
-- Name: app_categories(name); Type: FUNCTION; Schema: desktop; Owner: desktop
--

CREATE FUNCTION app_categories(name) RETURNS text
    AS 'select desktop.concat_strings(category||'';'') from app_category where app = $1 order by 1'
    LANGUAGE sql;


--
-- TOC entry 12 (OID 2072064)
-- Name: mime_globs(name); Type: FUNCTION; Schema: desktop; Owner: desktop
--

CREATE FUNCTION mime_globs(name) RETURNS text
    AS 'select desktop.concat_strings(pattern||'';'') from globs_corrected where type = $1 order by 1'
    LANGUAGE sql;


--
-- TOC entry 5 (OID 2072065)
-- Name: flow_dot(text); Type: FUNCTION; Schema: desktop; Owner: desktop
--

CREATE FUNCTION flow_dot(text) RETURNS text
    AS 'SELECT
 ''
digraph mime { 
 overlap=false;

'' || desktop.flow_dot_nodes($1) || ''

'' || desktop.flow_dot_edges($1) || ''
}
'' AS dot
'
    LANGUAGE sql;


--
-- TOC entry 4 (OID 2072038)
-- Name: SCHEMA desktop; Type: COMMENT; Schema: -; Owner: desktop
--

COMMENT ON SCHEMA desktop IS 'Open Desktop Database';


